@@ -5,7 +5,7 @@
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2022
-;; Version: 1.7
+;; Version: 1.9
 ;; Package-Requires: ((emacs "29.1") (compat "30"))
 ;; URL: https://github.com/minad/osm
 ;; Keywords: network, multimedia, hypermedia, mouse
@@ -893,7 +893,8 @@ Local per buffer since the overlays depend on the zoom level.")
               mwheel-scroll-left-function #'osm--zoom-out-wheel
               mwheel-scroll-right-function #'osm--zoom-in-wheel
               bookmark-make-record-function #'osm--bookmark-record-default
-              imenu-create-index-function #'osm--imenu-index)
+              imenu-create-index-function #'osm--imenu-index
+              mouse-shift-adjust-mode nil)
   (when (boundp 'mwheel-coalesce-scroll-events)
     (setq-local mwheel-coalesce-scroll-events t))
   (when (boundp 'pixel-scroll-precision-mode)
@@ -1672,8 +1673,8 @@ See `osm-search-server' and `osm-search-language' for customization."
              (osm--table-with-metadata
               results '((display-sort-function . identity)
                         (cycle-sort-function . identity)
-                        (eager-display . t))
-              nil t nil t))
+                        (eager-display . t)))
+             nil t nil t)
             results)
            (error "No selection"))))
     (osm--goto (cadr selected) (caddr selected)
